defaults = {
    'apt': {
        'packages': {
            'ffmpeg': {},
            'mpv': {},

        },
    },
    'backups': {
        'paths': {
            '/var/opt/navidrome',
        },
    },
    'navidrome': {
        'config': {
            'Address': '127.0.0.1',
            'DataFolder': '/var/opt/navidrome',
            'EnableExternalServices': False,
            'EnableInsightsCollector': False,
            'Port': 4533,
            'LastFM': {
                'Enabled': False,
            },
            'ListenBrainz': {
                'Enabled': False,
            },
            'Scanner': {
                'Schedule': '@every 72h',
            },
        },
    },
}


@metadata_reactor.provides(
    'zfs/datasets',
)
def zfs(metadata):
    zfs_base = metadata.get('navidrome/zfs_base', 'tank')
    return {
        'zfs': {
            'datasets': {
                f'{zfs_base}/navidrome': {},
                f'{zfs_base}/navidrome/install': {
                    'mountpoint': '/opt/navidrome',
                    'needed_by': {
                        'directory:/opt/navidrome',
                    },
                },
                f'{zfs_base}/navidrome/home': {
                    'mountpoint': '/var/opt/navidrome',
                    'needed_by': {
                        'directory:/var/opt/navidrome',
                    },
                },
            },
        },
    }


@metadata_reactor.provides(
    'navidrome/config/baseurl',
)
def baseurl(metadata):
    return {
        'navidrome': {
            'config': {
                'BaseUrl': f'https://{metadata.get('navidrome/domain')}',
            },
        },
    }


@metadata_reactor.provides(
    'nginx/vhosts/navidrome',
)
def nginx(metadata):
    if not node.has_bundle('nginx'):
        raise DoNotRunAgain

    return {
        'nginx': {
            'vhosts': {
                'navidrome': {
                    'domain': metadata.get('navidrome/domain'),
                    'locations': {
                        '/': {
                            'target': f'http://127.0.0.1:{metadata.get('navidrome/config/Port')}',
                            # some requests take a loooooong time (for example,
                            # "delete all missing files" will wait until
                            # everything has been purged from the database)
                            'proxy_read_timeout': '1h',
                        },
                    },
                    'website_check_path': '/app/',
                    'website_check_string': 'Navidrome Music Server',
                },
            },
        },
    }


@metadata_reactor.provides(
    'icinga2_api/navidrome/services',
)
def icinga_check_for_new_release(metadata):
    version = metadata.get('navidrome/version')
    return {
        'icinga2_api': {
            'pretalx': {
                'services': {
                    'NAVIDROME UPDATE': {
                        'command_on_monitored_host': '/usr/local/share/icinga/plugins/check_github_for_new_release navidrome/navidrome {}'.format(version),
                        'vars.notification.mail': True,
                        'check_interval': '60m',
                    },
                },
            },
        },
    }
